.. Niimpy documentation master file, created by
   sphinx-quickstart on Thu Jan 30 10:56:14 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Niimpy: behavioral data analysis
================================

Niimpy is a Python package for analyzing and quantifying behavioral data.  It uses
pandas to read data from disk, perform basic manipulations, and
provides many high-level functions for various types of data.

.. toctree::
   :maxdepth: 1
   :caption: About

   about/introduction
   about/installation
   about/architecture
   about/schema
   about/contribution_guide
   about/How-to-cite
   about/see-also

.. toctree::
   :maxdepth: 1
   :caption: Quick Start
   
   quick-start

.. toctree::
   :maxdepth: 1
   :caption: User guide
   
   user_guide/reading
   user_guide/basic-transformations 
   user_guide/preprocessing/index
   user_guide/Exploration
   user_guide/Analysis

.. toctree::
   :maxdepth: 1
   :caption: Demos

   demo/student_life_example


.. toctree::
   :caption: Data documentation
   :maxdepth: 1

   aware
   
.. toctree::
   :maxdepth: 1
   :caption: API reference

   api/modules




Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
